==> haskell-test-framework-hunit-0.3.0.2-1010-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-FPlWVu9vDM26ndl7sUFRTI
key:                  test-framework-hunit-0.3.0.2-FPlWVu9vDM26ndl7sUFRTI
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  564ec5c0c39deae679e39feeacc10685
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-FPlWVu9vDM26ndl7sUFRTI
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-Fx4BPXF2XRxF2TIoA34dKA

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-1011-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-9dCKFnrxt6ZB5ed6kCX3DV
key:                  test-framework-hunit-0.3.0.2-9dCKFnrxt6ZB5ed6kCX3DV
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  bbb81830ea68f80dfabe7a1144b0bee2
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-9dCKFnrxt6ZB5ed6kCX3DV
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-Kc9OwFUsEbSIbGkBHYU5GZ

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
